/*
 * gtkpasman
 * Copyright (C) 2003 Cyril Bellot
 * Copyright (C) 2013 David Guglielmi
 *
 * main.c
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <unistd.h>
#include <stdlib.h>
#include <getopt.h>
#include "gtkpasman_config.h"

#ifdef DISABLE_GSETTINGS
  #include "configread.h"
#else
  #include "settings.h"
#endif

#include "gtkui.h"

/*
 * usage
 * 	display command line options
 */
void
usage (char *prg)
{
  g_print ("Usage: %s [options] [password_file]\n"
	   "\n"
	   "valid options are:\n"
	   "  -n : Do not ask password at start\n", prg);

}

/*
 * main
 * 	parse arguments, call creations of windows and start the thing
 */
int
main (int argc, char *argv[])
{

  int c, initial_password = 1;

#ifdef DISABLE_GSETTINGS
  config_read ();
#else
  init_settings ();
#endif
  /* parse arguments */
  while ((c = getopt (argc, argv, "nh?")) != -1) {
    switch (c) {
      /* list position */
    case 'n':
      initial_password = 0;
      break;
      /* help */
    case '?':
    case 'h':
      usage (argv[0]);
      return 0;
    }
  }
  /* password file from command line */
  if (argc - optind > 0) {
    g_free (passwdfile);
    passwdfile = g_strdup (argv[optind]);
  }

  /* create window */
  init_gtk_ui ();
  start_gtk_ui (initial_password);

  return EXIT_SUCCESS;
}

